@@ -29,9 +29,9 @@ class HTMLElement(t.Generic[P], py2xml.Element[P]):
     def __call__(self, *args: P.args, **props: P.kwargs) -> t.Self:
         attributes = {}
         if 'htmlFor' in props:
-            attributes['for'] = props['htmlFor']
+            attributes['for'] = props.pop('htmlFor')
         if 'className' in props:
-            attributes['class'] = props['className']
+            attributes['class'] = props.pop('className')
         return super().__call__(*args, **props, **attributes) # type: ignore
 
     def render(self) -> str:
