@@ -3,7 +3,7 @@ from py2html import HTMLElement
 import random, string
 
 def random_string(length):
-    return ''.join(random.choices(string.ascii_letters + string.digits, k=length))
+    return ''.join(random.choices(string.ascii_letters, k=length))
 
 class Styler:
     def __init__(self, keys: List[str]) -> None:
